# --------------------------------------------------------------------------
# Copyright 2011, C12G Labs S.L.
#
# This file is part of OpenNebula VMware Drivers.
#
# OpenNebula VMware Drivers is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or the hope That it will be useful, but (at your
# option) any later version.
#
# OpenNebula VMware Drivers is distributed in WITHOUT ANY WARRANTY;
# without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License
# along with OpenNebula VMware Drivers . If not, see
# <http://www.gnu.org/licenses/>
# --------------------------------------------------------------------------

# ---------------------------------------------------------------------------- #
# Set up the environment for the driver                                        #
# ---------------------------------------------------------------------------- #

ONE_LOCATION = ENV["ONE_LOCATION"] if !defined?(ONE_LOCATION)

if !ONE_LOCATION
    BIN_LOCATION      = "/usr/bin"  if !defined?(BIN_LOCATION)
    ETC_LOCATION      = "/etc/one/" if !defined?(ETC_LOCATION)
    RUBY_LIB_LOCATION = "/usr/lib/one/ruby" if !defined?(RUBY_LIB_LOCATION)
else
    BIN_LOCATION      = ONE_LOCATION + "/bin" if !defined?(BIN_LOCATION)
    ETC_LOCATION      = ONE_LOCATION  + "/etc/" if !defined?(ETC_LOCATION)
    if !defined?(RUBY_LIB_LOCATION)
        RUBY_LIB_LOCATION = ONE_LOCATION  + "/lib/ruby" 
    end
end

$: << RUBY_LIB_LOCATION

require "OpenNebulaDriver"
require "CommandManager"

# Do host sustitution in the libvirt URI
LIBVIRT_URI.gsub!('@HOST@', @host)

# Common functions
def perform_action(command)
    command = BIN_LOCATION + "/tty_expect -u " + USERNAME + " -p " + PASSWORD + " " + command

    action_result = LocalCommand.run(command)

    if action_result.code == 0
        return action_result.stdout
    else
        log(command, action_result.stderr, action_result.stdout)
        return action_result.code
    end
end

def log(cmd, stdout, stderr)
    STDERR.puts "[VMWARE] cmd failed [" + cmd +
                "]. Stderr: " + stderr + ". Stdout: " + stdout
end
